colour.colorimetry.dataset.cmfs Module — Colour 0.3.0 documentation

# colour.colorimetry.dataset.cmfs Module

## Colour Matching Functions Spectral Power Distributions

Defines various colour matching functions involved in spectral computations.

The colour matching functions data is in the form of a dict of `colour.colorimetry.spectrum.TriSpectralPowerDistribution` classes as follows:

    {'name': TriSpectralPowerDistribution,
    ...,
    'name': TriSpectralPowerDistribution}

The following colour matching functions are available:

- Stockman & Sharpe 2 Degree Cone Fundamentals [1]
- Stockman & Sharpe 10 Degree Cone Fundamentals [1]
- Wright & Guild 1931 2 Degree RGB CMFs [2]
- Stiles & Burch 1955 2 Degree RGB CMFs [3]
- Stiles & Burch 1959 10 Degree RGB CMFs [4]
- CIE 1931 2 Degree Standard Observer [5]
- CIE 1964 10 Degree Standard Observer [5]
- CIE 2012 10 Degree Standard Observer [6]
- CIE 2012 2 Degree Standard Observer [6]

See also

Colour Matching Functions IPython Notebook

Notes

- Stockman & Sharpe LMS colour matching functions are provided at 1 nm steps.
- Wright & Guild and Stiles & Burch CIE RGB colour matching functions are provided at 5 nm steps.
- CIE Standard Observers XYZ colour matching functions are provided at 5 nm steps.

References

[1] | (1, 2) http://www.cvrl.org/cones.htm (Last accessed 23 June 2014)

[2] | http://www.cis.rit.edu/mcsl/research/1931.php (Last accessed 12 June 2014)

[3] | http://www.cvrl.org/stilesburch2_ind.htm (Last accessed 24 February 2014)

[4] | http://www.cvrl.org/stilesburch10_ind.htm (Last accessed 24 February 2014)

[5] | (1, 2) http://cvrl.ioo.ucl.ac.uk/cie.htm (Last accessed 24 February 2014)

[6] | (1, 2) http://cvrl.ioo.ucl.ac.uk/ciexyzpr.htm (Last accessed 24 February 2014)

`colour.colorimetry.dataset.cmfs.` `LMS_CMFS` = CaseInsensitiveMapping({u'Stockman & Sharpe 2 Degree Cone Fundamentals': <colour.colorimetry.cmfs.LMS_ConeFundamentals object at 0x102cf5590>, u'Stockman & Sharpe 10 Degree Cone Fundamentals': <colour.colorimetry.cmfs.LMS_ConeFundamentals object at 0x102cf55d0>})

  LMS colour matching functions.

  LMS_CMFS : dict
    (‘Stockman & Sharpe 2 Degree Cone Fundamentals’, ‘Stockman & Sharpe 10 Degree Cone Fundamentals’)

`colour.colorimetry.dataset.cmfs.` `RGB_CMFS` = CaseInsensitiveMapping({u'Stiles & Burch 1959 10 Degree RGB CMFs': <colour.colorimetry.cmfs.RGB_ColourMatchingFunctions object at 0x102cf5a90>, u'Wright & Guild 1931 2 Degree RGB CMFs': <colour.colorimetry.cmfs.RGB_ColourMatchingFunctions object at 0x102cf5910>, u'Stiles & Burch 1955 2 Degree RGB CMFs': <colour.colorimetry.cmfs.RGB_ColourMatchingFunctions object at 0x102cf5810>})

  CIE RGB colour matching functions.

  RGB_CMFS : dict
    (‘Wright & Guild 1931 2 Degree RGB CMFs’, ‘Stiles & Burch 1955 2 Degree RGB CMFs’, ‘Stiles & Burch 1959 10 Degree RGB CMFs’)

`colour.colorimetry.dataset.cmfs.` `STANDARD_OBSERVERS_CMFS` = CaseInsensitiveMapping({u'CIE 1931 2 Degree Standard Observer': <colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5c10>, u'cie_10_1964': <colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5bd0>, u'CIE 2012 10 Degree Standard Observer': <colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5d90>, u'CIE 2012 2 Degree Standard Observer': <colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5dd0>, u'CIE 1964 10 Degree Standard Observer': <colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5bd0>, u'cie_2_1931': <colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5c10>})

  CIE Standard Observers XYZ colour matching functions.

  STANDARD_OBSERVERS_CMFS : dict
    (‘CIE 1931 2 Degree Standard Observer’, ‘CIE 1964 10 Degree Standard Observer’, ‘CIE 2012 2 Degree Standard Observer’, ‘CIE 2012 10 Degree Standard Observer’)

  Aliases:

  - ‘cie_2_1931’: ‘CIE 1931 2 Degree Standard Observer’
  - ‘cie_10_1964’: ‘CIE 1964 10 Degree Standard Observer’

`colour.colorimetry.dataset.cmfs.` `CMFS` = CaseInsensitiveMapping({u'Stockman & Sharpe 2 Degree Cone Fundamentals': <colour.colorimetry.cmfs.LMS_ConeFundamentals object at 0x102cf5590>, u'CIE 1931 2 Degree Standard Observer': <colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5c10>, u'CIE 2012 10 Degree Standard Observer': <colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5d90>, u'cie_10_1964': <colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5bd0>, u'Stockman & Sharpe 10 Degree Cone Fundamentals': <colour.colorimetry.cmfs.LMS_ConeFundamentals object at 0x102cf55d0>, u'Wright & Guild 1931 2 Degree RGB CMFs': <colour.colorimetry.cmfs.RGB_ColourMatchingFunctions object at 0x102cf5910>, u'CIE 2012 2 Degree Standard Observer': <colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5dd0>, u'Stiles & Burch 1959 10 Degree RGB CMFs': <colour.colorimetry.cmfs.RGB_ColourMatchingFunctions object at 0x102cf5a90>, u'cie_2_1931': <colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5c10>, u'CIE 1964 10 Degree Standard Observer': <colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5bd0>, u'Stiles & Burch 1955 2 Degree RGB CMFs': <colour.colorimetry.cmfs.RGB_ColourMatchingFunctions object at 0x102cf5810>})

  Aggregated colour matching functions.

  CMFS : dict
    (‘Stockman & Sharpe 10 Degree Cone Fundamentals’, ‘Stockman & Sharpe 2 Degree Cone Fundamentals’, ‘Wright & Guild 1931 2 Degree RGB CMFs’, ‘Stiles & Burch 1955 2 Degree RGB CMFs’, ‘Stiles & Burch 1959 10 Degree RGB CMFs’, ‘CIE 1931 2 Degree Standard Observer’, ‘CIE 1964 10 Degree Standard Observer’, ‘CIE 2012 2 Degree Standard Observer’, ‘CIE 2012 10 Degree Standard Observer’)